import * as graphql from 'graphql';
interface INullableTypeOption {
    type: string;
    defaultVal: graphql.ValueNode | null;
    isArgument: boolean;
}
export interface IParseOption {
    /** 以哪种方式转换enum类型，可以转换为enum或type，默认type */
    enumType?: 'enum' | 'type';
    /** 以哪种方式转换对象类型，默认interface */
    objectType?: 'interface' | 'type';
    /** 命名空间名称，默认gql */
    namespaceName?: string;
    /** 输出类型，export、declare、none，默认declare */
    outputType?: 'export' | 'declare' | 'none';
    /** 是否将参数转换为interface类型，默认false */
    argument2interface?: boolean;
    /** 自定义标量类型, 默认为：`{String: 'string', Boolean: 'boolean', Int: 'number', Float: 'number', ID: 'string | number'}` */
    customscalarTypes?: {
        [P in 'String' | 'Boolean' | 'Int' | 'Float' | 'ID' | string]?: string;
    };
    /** 可以为空的数据类型，默认全部都是：type=>type+' | null | undefined' */
    nullableType?: {
        [P in 'input' | 'interface' | 'object']?: (option: INullableTypeOption) => string;
    };
    /** 是否将带默认值的参数转换为非空，默认true */
    notNullWhenDefaultValue?: boolean;
}
/**
 * 转换一个graphql schema为typescript定义文件
 * @param schema 要转换的schema
 * @param param1 转换选项
 */
export declare function parse(schema: graphql.GraphQLSchema, { enumType, objectType, namespaceName, outputType, argument2interface, customscalarTypes, nullableType, notNullWhenDefaultValue, }?: IParseOption): string;
export {};
